@@ -15,14 +15,15 @@ from pstats import Stats
 
 from jinja2 import Environment, PackageLoader
 
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 __licence__ = 'New BSD License'
 __author__ = 'Hideo Hattori <hhatto.jp@gmail.com>'
 
 __all__ = ['Converter']
 
+CODEC = 'utf-8'
 ENVIRON = Environment(loader=PackageLoader('pyprof2html',
-                      './templates', encoding='utf-8'))
+                      './templates', encoding=CODEC))
 
 
 def check_hotlinetimings(dump):
@@ -38,7 +39,8 @@ def check_hotshot(dump):
 
 
 def mapping_table(target, nall):
-    levelmap = {0: '#ccffcc',   # yellow green (light)
+    levelmap = {0: '#ffffff',   # white
+                #0: '#ccffcc',   # yellow green (light)
                 1: '#66ff99',   # yellow green
                 2: '#ffcc33',   # orange
                 3: '#ff6666',   # pink
@@ -97,10 +99,10 @@ def convert_unit(float_number):
 
 
 def create_stylefile(output_directory):
-    """create to ./style.css and jquery.js file"""
-    for filename in ('style.css', 'jquery.js', 'jquery.tablesorter.js'):
-        fp = open('./%s/%s' % (output_directory, filename), 'w')
-        print >> fp, ENVIRON.get_template(filename).render()
+    """create to style.css and jquery.js file"""
+    for filename in ('style.css', 'jquery.js', 'jquery.tablesorter.min.js'):
+        fp = open('%s/%s' % (output_directory, filename), 'w')
+        print >> fp, ENVIRON.get_template(filename).render().encode(CODEC)
         fp.close()
 
 
@@ -115,7 +117,7 @@ class Converter(object):
         dump = open(filename).read()
         if check_hotshot(dump[:20]):
             self.prof = stats.load(filename)
-            self.tmpl = ENVIRON.get_template('basic.html')
+            self.tmpl = ENVIRON.get_template('base.html')
             self.profile_datatype = "hotshot"
             if check_hotlinetimings(dump[102:108]):
                 self.profline = log.LogReader(filename)
@@ -123,7 +125,7 @@ class Converter(object):
                 self.profile_datatype = "hotshot(line)"
         else:
             self.prof = Stats(filename)
-            self.tmpl = ENVIRON.get_template('basic.html')
+            self.tmpl = ENVIRON.get_template('base.html')
             self.profile_datatype = "cProfile"
         self.filename = filename
         self.proftime = time.ctime(os.stat(filename).st_mtime)
@@ -163,7 +165,7 @@ class Converter(object):
         if filecodec is None:
             print >> outputfile, self.tmplline.render(renderdict)
         else:
-            self.tmplline.stream(renderdict).dump(outputfile, 'utf-8')
+            self.tmplline.stream(renderdict).dump(outputfile, CODEC)
 
     def _print_source(self, filename, profs):
         """printing one file profile line. return value is text strings.
@@ -235,11 +237,9 @@ class Converter(object):
         self.prof.stream = backstream
         self.prof.stream.close()
         datalist = list()
-        cnt = 0
-        for func in funclist:
+        for cnt, func in enumerate(funclist):
             if cnt >= self.functions_number:
                 break
-            cnt += 1
             stat = self.prof.stats[func]
             ncalls = stat[0]
             if not int(ncalls):
@@ -259,8 +259,8 @@ class Converter(object):
             ncallslevel = mapping_table(ncalls, self.prof.total_calls)
             tottlevel = mapping_table(stat[2], self.prof.total_tt)
             totclevel = mapping_table(float(totpercall), self.prof.total_tt)
-            cumtlevel = mapping_table(1, 1000)
-            cumclevel = mapping_table(1, 1000)
+            cumtlevel = mapping_table(stat[3], self.prof.total_tt)
+            cumclevel = mapping_table(float(cumpercall), self.prof.total_tt)
             linelink = "%s.html" % func[0].replace('/', '_')
             data = {
                 'func': func,
