@@ -3,9 +3,11 @@
 
 require pikzie module(http://pikzie.sourceforge.net/)
 """
-
+import os
+import shutil
 import sys
-sys.path.insert(0, './pyprof2html')     ## test to development path
+import tempfile
+sys.path.insert(0, './pyprof2html')     # test to development path
 import pyprof2html as p2h
 
 # warning handling
@@ -58,7 +60,25 @@ hotshot_testdata_path = './test/hot.prof'
 cprof_testdata_path = './test/cprof.prof'
 
 
-class TestExecute(pikzie.TestCase):
+class TestExecuteHtml(pikzie.TestCase):
+
+    def test_cprofhtml(self):
+        prof = p2h.Converter(cprof_testdata_path)
+        prof.printout('html')
+        self.assert_equal(True, True)
+
+    def test_hotshothtml(self):
+        prof = p2h.Converter(hotshot_testdata_path)
+        prof.printout('html')
+        self.assert_equal(True, True)
+
+    def test_hotshotlinehtml(self):
+        prof = p2h.Converter(hotshotline_testdata_path)
+        prof.printout('html')
+        self.assert_equal(True, True)
+
+
+class TestExecuteRaw(pikzie.TestCase):
 
     def setup(self):
         self.defaultstdout = sys.stdout
@@ -72,26 +92,11 @@ class TestExecute(pikzie.TestCase):
         prof.printout('raw')
         self.assert_equal(True, True)
 
-    def test_cprofhtml(self):
-        prof = p2h.Converter(cprof_testdata_path)
-        prof.printout('html')
-        self.assert_equal(True, True)
-
     def test_hotshotraw(self):
         prof = p2h.Converter(hotshot_testdata_path)
         prof.printout('raw')
         self.assert_equal(True, True)
 
-    def test_hotshothtml(self):
-        prof = p2h.Converter(hotshot_testdata_path)
-        prof.printout('html')
-        self.assert_equal(True, True)
-
-    def test_hotshotlinehtml(self):
-        prof = p2h.Converter(hotshotline_testdata_path)
-        prof.printout('html')
-        self.assert_equal(True, True)
-
 
 class ColorMappingTest(pikzie.TestCase):
 
@@ -169,3 +174,21 @@ class FindFileCodec(pikzie.TestCase):
     def test_vim_style1_shiftjis(self):
         ret = p2h.detect_filecodec(["# vim: fileencoding=shift_jis"])
         self.assert_equal(ret, 'shift_jis')
+
+
+class CreateStylefile(pikzie.TestCase):
+
+    def setup(self):
+        self.dirname = tempfile.mkdtemp()
+
+    def teardown(self):
+        shutil.rmtree(self.dirname)
+
+    def test_create_ok(self):
+        p2h.create_stylefile(self.dirname)
+        path = self.dirname + '/style.css'
+        self.assert_equal(True, os.path.exists(path))
+        path = self.dirname + '/jquery.js'
+        self.assert_equal(True, os.path.exists(path))
+        path = self.dirname + '/jquery.tablesorter.min.js'
+        self.assert_equal(True, os.path.exists(path))
